import ssl
import json
import yaml
import time
import boto3
from botocore.exceptions import NoCredentialsError

from datetime import datetime, timezone, timedelta

class sdtclouds3():
    def __init__(self):
        appId, deviceConfig = self.getConfig()
        if appId == "":
            appId = "execution"

        self.s3Id = deviceConfig["s3id"]
        self.s3Key = deviceConfig["s3key"]
        # self.bucket = deviceConfig["servicecode"]
        self.bucket = deviceConfig["projectcode"]
        self.s3Path = f"{deviceConfig['assetcode']}/app/{appId}/data"
        self.s3 = boto3.client('s3', aws_access_key_id=self.s3Id, aws_secret_access_key=self.s3Key)

    def getConfig(self):

        with open('/etc/sdt/device.config/app.json', encoding='UTF-8') as f:
            appConfig = json.load(f)
        
        with open('./framework.yaml', encoding='UTF-8') as f:
            appFramework = yaml.load(f, Loader=yaml.FullLoader)
        
        appId = ""
        for appInfo in appConfig["AppInfoList"]:
            if appInfo["AppName"] == appFramework["spec"]["appName"]:
                appId = appInfo["AppId"]

        with open('/etc/sdt/device.config/config.json', encoding='UTF-8') as f:
            deviceConfig = json.load(f)

        return appId, deviceConfig
    

    def uploadData(self, targetData, extra):
        extraArgs = {
            "ACL": "public-read"
        }

        try:
            dataName = targetData.split("/")[-1]
            if extraArgs == "":
                self.s3.upload_file(targetData, self.bucket, f"{self.s3Path}/{dataName}")
            else:
                extraArgs.update(extra)
                self.s3.upload_file(targetData, self.bucket, f"{self.s3Path}/{dataName}", ExtraArgs=extraArgs)
            dataUrl = f"https://{self.bucket}.s3.ap-northeast-2.amazonaws.com/{self.s3Path}/{dataName}"
            print("Success upload data.")
            return dataUrl
        except FileNotFoundError:
            print("Not found your file.")
            return ""
        except NoCredentialsError:
            print("Not found aws user.")
            return ""        

    def downloadData(self, targetData, downloadPath):
        try:
            s3FilePath = f"{self.s3Path}/{targetData}"
            fileLocalPath = f"{downloadPath}/{targetData}"
            # print(s3FilePath)
            # print(fileLocalPath)
            self.s3.download_file(self.bucket, s3FilePath, fileLocalPath)
            print(f"Success download data.: {fileLocalPath}")
        except FileNotFoundError:
            print("Not found file in s3")
        except NoCredentialsError:
            print("Not found aws user.")
    